#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 microaeson
version:              0.1.0.3
visibility:           public
id:                   microaeson-0.1.0.3-3yUM2zorVmK5OUnE0w7se8
key:                  microaeson-0.1.0.3-3yUM2zorVmK5OUnE0w7se8
license:              GPL-3.0-only
maintainer:           Andreas Abel
author:               Herbert Valerio Riedel
synopsis:             A tiny JSON library with light dependency footprint
description:
    @microaeson@ aims to provide a [RFC 8259](https://tools.ietf.org/html/rfc8259) compliant JavaScript Object Notation (JSON) implementation.
    The [microaeson](https://hackage.haskell.org/package/microaeson) package provides a smaller subset of the [aeson](https://hackage.haskell.org/package/aeson) API with less dependencies and a simpler implementation.

    The API is designed in such a way to allow to easily convert client code written against @microaeson@'\''s API to use the full [aeson](https://hackage.haskell.org/package/aeson) API.

category:             Text, Web, JSON
abi:                  44f17edc22b099d09ec023d68f84f7d6
exposed:              True
exposed-modules:      Data.Aeson.Micro
hidden-modules:       Data.Aeson.Micro.Parser Data.Aeson.Micro.Scanner
import-dirs:          /usr/lib/ghc-9.6.6/site-local/microaeson-0.1.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/microaeson-0.1.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/microaeson-0.1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microaeson
hs-libraries:         HSmicroaeson-0.1.0.3-3yUM2zorVmK5OUnE0w7se8
depends:
    array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    deepseq-1.4.8.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-microaeson/html/microaeson.haddock
haddock-html:         /usr/share/doc/haskell-microaeson/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

